package com.aitrainer.api.controller

import com.aitrainer.api.model.ExercisePlan
import com.aitrainer.api.repository.ExercisePlanRepository
import org.slf4j.LoggerFactory
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*
import javax.validation.Valid

@RestController
@RequestMapping("/api")
class ExercisePlanController( private val exercisePlanRepository: ExercisePlanRepository) {
    private val logger = LoggerFactory.getLogger(javaClass)

    @PostMapping("/exercise_plan")
    fun createNewExercisePlan(@Valid @RequestBody exercisePlan: ExercisePlan): ResponseEntity<ExercisePlan> {
        val newExercisePlan = exercisePlanRepository.save(exercisePlan)
        logger.info("Create new exercise plan: $newExercisePlan")
        return ResponseEntity.ok().body(newExercisePlan)
    }

    @GetMapping("/exercise_plan/last/{customerId}")
    fun getLastExercisePlan(@PathVariable(value = "customerId") customerId: Long): ResponseEntity<ExercisePlan> {

        val exercisePlan  = exercisePlanRepository.getLastExercisePlan(customerId)
        logger.info("Get last exercise plan by id $customerId: $exercisePlan")

        return if( exercisePlan != null)
            ResponseEntity.ok().body(exercisePlan) else
            ResponseEntity.notFound().build()
    }
}